@@ -146,7 +146,7 @@ def generate_packer_json(region, sami, instance_type, appname, vpc, subnet):
       }},
       {{
             "type": "shell",
-            "inline": "rm -f /root/.ssh/authorized_keys",
+            "inline": "sudo rm -f /root/.ssh/authorized_keys",
             "only": ["amazon-ebs"]
           }}
   ]
